==> UPS-courier_v1.4.1.zip: UPS-courier v1.4.1/UPS-courier v1.4.1.oxp/Scripts/demoScript.js <==
this.name        = "demo"; 
this.author      = "eric walch"; 
this.copyright   = " 2008 the Oolite team."; 
this.description = "Empty script structure"; 
this.version     = "0.0"; 


// this only runs at startup. Will hardly be needed.
this.startUp = function()
{
}

// this runs after a startup or after a restart. missionVariables are still undefined at this point.
this.reset = function()
{
    this.mustPopulate = true
    /* used for adding ships after a first launch.
    This way you don't have to time consuming check every launch if a ship was already there.
    */
}

this.shipDockedWithStation = function()
{
        if(player.docked) this.missionOffers()
}

this.missionOffers = function()
{
    if (guiScreen == "GUI_SCREEN_MISSION") return; // there will be a "missionScreenEnded" in future to react uppon.
    if (missionVariables.offering || (mission.choice && mission.choice != "")) return;
    if (player.dockedStation.isMainStation)
    {
        //  Your stuff for the main station
        /*
        Starting with 1.71 setting up a missionscreen became much easier. All the standard stuff is handled
        when using the command:
        mission.runMissionScreen("mission_text", "backgroundscreen.png", "choices_text", "ship_role", "music")
        You can transfer 5 variables at once that formerly had to set or cleared each seperately.
        When not needed you can transfer a nill. nill's at the end can be omittet, in between must be used.
        */
    }
    if ((player.dockedStation.shipDescription == "My Station")
    {
        // Your stuff for a special named station
    }
}

this.choiceEvaluation = function()
{
    if (missionVariables.offering == "MY_OFFER")
    {
         /* It is saver to not use a simple YES, but use a YES_MISSION. This just for the case there is
         a conflict with an other bad written oxp that also has a YES. */
        if(mission.choice == "YES_MISSION")
        {
            // put your code here. 
            missionVariables.offering = null
            mission.choice = null
            /* resetting the mission.choice triggers the "missionChoiceWasReset" handler. 
            therefor this must always happen after other variables are reset to prefent that the script
            tries to run again.  */
        }
        else
        {
            if (mission.choice == "NO_MISSION")
            {
                // put your code here
                missionVariables.offering = null
                mission.choice = null
            } else {missionVariables.offering = null} // one should never get here.
        }
    }
}

this.missionScreenEnded = function()
{
    if(!player.docked) return;
    if(mission.choice) this.choiceEvaluation()
    this.missionOffers()
}

this.missionChoiceWasReset = function()
{
    if(!player.docked) return;
    this.missionOffers()
}

this.setUpShips = function()
{
    // Put here your code that populates the system.
}

this.shipExitedWitchspace = function()
{
    if(system.isInterstellarSpace) return;
    this.setUpShips();
    // Put here your code else than setting ships up.
}

this.playerEnteredNewGalaxy = function()
{
    // This handler will be rarely needed.
}

this.shipLaunchedFromStation = function()
{
   /* The first launch after a restart the system must be populated after a launch.
   The other times it happens after a WitchspaceJump */
   if(this.mustPopulate) {this.setUpShips(); this.mustPopulate = false}
    // put here your other code.
}

==> UPS-courier_v1.4.2.zip: UPS-courier v1.4.2/UPS-courier v1.4.2.oxp/Scripts/demoScript.js <==
this.name        = "demo"; 
this.author      = "eric walch"; 
this.copyright   = " 2008 the Oolite team."; 
this.description = "Empty script structure"; 
this.version     = "0.0"; 


// this only runs at startup. Will hardly be needed.
this.startUp = function()
{
}

// this runs after a startup or after a restart. missionVariables are still undefined at this point.
this.reset = function()
{
    this.mustPopulate = true
    /* used for adding ships after a first launch.
    This way you don't have to time consuming check every launch if a ship was already there.
    */
}

this.shipDockedWithStation = function()
{
        // an other eventhandler cauld have launched the ship already.
        if(player.docked) this.missionOffers()
}

this.missionOffers = function()
{
    if (guiScreen == "GUI_SCREEN_MISSION") return; // there will be a "missionScreenEnded" in future to react uppon.
    if (missionVariables.offering || (mission.choice && mission.choice != "")) return;
    if (player.dockedStation.isMainStation)
    {
        //  Your stuff for the main station
        /*
        Starting with 1.71 setting up a missionscreen became much easier. All the standard stuff is handled
        when using the command:
        mission.runMissionScreen("mission_text", "backgroundscreen.png", "choices_text", "ship_role", "music")
        You can transfer 5 variables at once that formerly had to set or cleared each seperately.
        When not needed you can transfer a nill. nill's at the end can be omittet, in between must be used.
        */
    }
    if (player.dockedStation.shipDescription == "My Station")
    {
        // Your stuff for a special named station
    }
}

this.choiceEvaluation = function()
{
    if (missionVariables.offering == "MY_OFFER")
    {
         /* It is saver to not use a simple YES, but use a YES_MISSION. This just for the case there is
         a conflict with an other bad written oxp that also has a YES. */
        if(mission.choice == "YES_MISSION")
        {
            // put your code here. 
            missionVariables.offering = null
            mission.choice = null
            /* resetting the mission.choice triggers the "missionChoiceWasReset" handler. 
            therefor this must always happen after other variables are reset to prefent that the script
            tries to run again.  */
        }
        else
        {
            if (mission.choice == "NO_MISSION")
            {
                // put your code here
                missionVariables.offering = null
                mission.choice = null
            } else {missionVariables.offering = null} // one should never get here.
        }
    }
}

this.missionScreenEnded = function()
{
    if(!player.docked) return;
    if(mission.choice) this.choiceEvaluation()
    this.missionOffers()
}

this.missionChoiceWasReset = function()
{
    if(!player.docked) return;
    this.missionOffers()
}

this.setUpShips = function()
{
    // Put here your code that populates the system.
}

this.shipExitedWitchspace = function()
{
    if(system.isInterstellarSpace) return;
    this.setUpShips();
    // Put here your code else than setting ships up.
}

this.playerEnteredNewGalaxy = function()
{
    // This handler will be rarely needed.
}

this.shipLaunchedFromStation = function()
{
   /* The first launch after a restart the system must be populated after a launch.
   The other times it happens after a WitchspaceJump */
   if(this.mustPopulate) {this.setUpShips(); this.mustPopulate = false}
    // put here your other code.
}
